//========================================================
// File		: Hardware.c
// Author	: wzh
// Version	: V1.0
// Date		: 20.09.29
//========================================================

//========================================================
// Section: Included Files
//========================================================
#include "../main.h"
#include "../Library/Device/Include/ML51.h"
//========================================================
// Section: Macro Declarations
//========================================================

//========================================================
#if		1
//========================================================
// Function	  	: Hardware_Init
// Function API : 
// param[in]	: None
// note			: None
// return		: None
// exmaple		: Hardware_Init();
//========================================================
void Hardware_Init(void)
{
	//========================================================
	//----OSCILLATOR Initialize-------------------------------
	//========================================================
		SFRS = 0x00;
		//========================================================
		// step1: enable HIRC clock source run
		TA = 0xAA;	TA = 0x55;
		CKEN =			// Clock Enable (TA protected)
				(0<<7)| // EHXTEN[7]	: External High-speed crystal/resonator enable
						// EHXTEN = 0;	external crystal/resonator 4-24 MHz Disabled.
						//				P5.2 and P5.3 work as general purpose I/O or other functions if ECLKEN set to 0.
				(0<<6)| // ELXTEN[6]	: External Low-speed crystal/resonator enable
						// ELXTEN = 0;	Low-speed external crystal/resonator 32.768kHz Disabled.
						//				P5.4 and P5.5 work as general purpose I/O or other functions.
				(1<<5)| // HIRCEN[5]	: High-speed internal oscillator 24 MHz enable
				(1<<4)| // LIRCEN[4]	: Low speed internal oscillator 38.4 kHz enable 		  for WDT&WKT lichi20200630
				(0<<3)| // ECLKEN[3]	: External Clock Input enable
				(1<<2)| // Reserved, value after reset is 1
				(0<<1)| // Reserved, value after reset is 0
				(0<<0); // CKSWTF[0]	: Clock switch fault flag
						// Once user switches the system clock source to an enabled but still instable one, the hardware will wait for
						// stabilization of the target clock source and then switch to it in the background.
		//========================================================
		// step2: check clock source status and wait for ready
		while((CKSWT&SET_BIT5)==0);
		//========================================================
		TA = 0xAA;	TA = 0x55;
		CKSWT = 		// CKSWT: Clock Switch (TA protected)
				(0<<7)| // HXTST[7] : High speed external crystal/resonator 4 MHz to 24 MHz status 
						// HXTST = 1;	High speed external crystal/resonator is enabled and stable.
				(0<<6)| // LXTST[6] : Low speed external crystal/resonator 32.768 kHz status
						// LXTST = 1;	Low speed external crystal/resonator is enabled and stable.
				(1<<5)| // HIRCST[5]: High-speed internal oscillator 24 MHz status
						// HIRCST = 1;	High-speed internal oscillator is enabled and stable.
				(1<<4)| // LIRCST[4]: Low speed internal oscillator 38.4 kHz status
						// LIRCST = 1;	Low speed internal oscillator is enabled and stable.	for WDT&WKT lichi20200630
				(0<<3)| // ECLKST[3]: External clock input status.
						// ECLKST = 1;	External clock input is enabled and stable.
				(0<<0); // OSC[2:0]: This field selects the system clock source.
						// OSC = 0; Internal 24 MHz oscillator. Defaul value accoding to HIRCEN(CKEN.5) enabled.	
		//========================================================
		// step4: check system clock switching OK or NG
		while((CKEN&SET_BIT0)==1);
		//========================================================
		// step5: enable ECLK clock source run
		TA = 0xAA;	TA = 0x55;
		CKEN &= 0x37;
	//========================================================
	//----Gpio Config and PIN interrupt-----------------------
	//========================================================
		SFRS = 0x01;
		//========================================================
		//----Function_Gpio---------------------------------------
		// Device:		P24_RED_LED			P25_GREEN_LED		Push-Pull Mode
		//				P03_MUSIC_VBAT_CONTROL					Push-Pull Mode
		//				P21_MUSIC_PULS		P22_MUSIC_RESET		Push-Pull Mode
		//				P23_MUSIC_nPLAYING	P46_Key				In-Put Mode
		// NB-IOT/PC:											Push-Pull Mode
		//								 						In-Put Mode
		// SmokeMode:											Push-Pull Mode
		//				P00_Init	P01_Wakeup					In-Put Mode	
		//				P02_Alarm	P20_IO4						In-Put Mode
		//----UART_Gpio-------------------------------------------
		// UART0: P17_UART0_RXD 	P16_UART0_TXD				NB-IOT/PC
		// UART2: P40_UART2_RXD 	P41_UART2_TXD				SmokeMode
		//========================================================
		// PnM1.x	PnM2.x
		//	0		0		Quasi-bidirectiona
		//	0		1		Push-pull
		//	1		0		Input-only (high-impedance)
		// 	1		1		Open-drain
		// PnUP.x = 0: pull-up Disabled			// PnUP.x = 1: pull-up Enabled
		// PnDW.x = 0: pull-down Disabled		// PnDW.x = 1: pull-down Enabled
		// PnSR.x = 0: normal output slew rate	// PnSR.x = 1: high-speed output slew rate
		// PnS.x  = 0: TTL level input			// PnS.x  = 1: Schmitt triggered input
		//========================================================
		// P0: --/--/--/--/
		// P0: P03_MUSIC_VBAT_CONTROL/P02_Alarm/P01_Wakeup/P00_Init
		//========================================================
		P0M1 = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(0<<3)|(1<<2)|(1<<1)|(1<<0);
		P0M2 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(1<<3)|(1<<2)|(0<<1)|(0<<0);
		P0UP = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(1<<3)|(0<<2)|(0<<1)|(0<<0);
		P0DW = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(0<<3)|(0<<2)|(1<<1)|(1<<0);
		P0SR = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P0S	 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		//========================================================
		// P1: P17_UART0_RXD/P16_UART0_TXD/--/--
		// P1: --/--/--/--
		//========================================================
		P1M1 = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(1<<1)|(1<<0);	
		P1M2 = (0<<7)|(1<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P1UP = (1<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P1DW = (0<<7)|(0<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(1<<1)|(1<<0);
		P1SR = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P1S	 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		//========================================================
		// P2: --/--/P25_GREEN_LED/P24_RED_LED/
		// P2: P23_MUSIC_nPLAYING/P22_MUSIC_RESET/P21_MUSIC_PULS/P20_IO4
		//========================================================
		P2M1 = (1<<7)|(1<<6)|(0<<5)|(0<<4)|(1<<3)|(0<<2)|(0<<1)|(1<<0);	
		P2M2 = (0<<7)|(0<<6)|(1<<5)|(1<<4)|(0<<3)|(1<<2)|(1<<1)|(1<<0);
		P2UP = (0<<7)|(0<<6)|(1<<5)|(1<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P2DW = (1<<7)|(1<<6)|(0<<5)|(0<<4)|(1<<3)|(1<<2)|(1<<1)|(0<<0);
		P2SR = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P2S	 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		//========================================================
		// P3: --/--/--/--
		// P3: --/--/--/--
		//========================================================
		P3M1 = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(1<<1)|(1<<0);	
		P3M2 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P3UP = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P3DW = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(1<<1)|(1<<0);
		P3SR = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P3S	 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		//========================================================
		// P4: --/P46_Key/--/--
		// P4: --/--/P41_UART2_TXD/P40_UART2_RXD
		//========================================================
		P4M1 = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(1<<1)|(1<<0);	
		P4M2 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(1<<1)|(0<<0);
		P4UP = (0<<7)|(1<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(1<<0);
		P4DW = (1<<7)|(0<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(0<<1)|(0<<0);
		P4SR = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P4S	 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		//========================================================
		// P5: --/--/--/--
		// P5: --/--/IIC0_SCL/IIC0_SDA
		//========================================================
		P5M1 = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(0<<1)|(0<<0);	
		P5M2 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P5UP = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P5DW = (1<<7)|(1<<6)|(1<<5)|(1<<4)|(1<<3)|(1<<2)|(0<<1)|(0<<0);
		P5SR = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		P5S	 = (0<<7)|(0<<6)|(0<<5)|(0<<4)|(0<<3)|(0<<2)|(0<<1)|(0<<0);
		//========================================================
		LED_PIN_RED = 1;
		LED_PIN_GREEN = 1;
		//========================================================
		//--P01_WAKEUP----High-level/falling-edge Wakeup interrupt
		//--P46_Key-------Low-level/falling-edge Wakeup interrupt-
		//--P40_UART2_RXD-Low-level/falling-edge Wakeup interrupt-
		//--P17_UART0_RXD-Low-level/falling-edge Wakeup interrupt-
		//========================================================
		PICON = 0x33;	// E9H, Page 1
						// 0 = Level triggered.
						// 1 = Edge triggered.
		PINEN = 0x32;	// EAH, Page 1	Pin Interrupt Negative Polarity Enable.
						// 0 = Low-level/falling edge detect Disabled.
						// 1 = Low-level/falling edge detect Enabled.
		PIPEN = 0x01;	// EBH, Page 1	Pin Interrupt Positive Polarity Enable.
						// 0 = High-level/rising edge detect Disabled.
						// 1 = High-level/rising edge detect Enabled.
		PIPS0 = 
				(0<<4)| // PSEL[6:4]	Pin interrupt channel Port select	000 = P0 PORT.
				(1<<0); // BSEL[2:0]	Pin interrupt channel bit select	001 = Pn.1. 
		PIPS1 = 
				(4<<4)| // PSEL[6:4]	Pin interrupt channel Port select	000 = P0 PORT.
				(6<<0); // BSEL[2:0]	Pin interrupt channel bit select	001 = Pn.1. 
		PIPS4 = 
				(4<<4)| // PSEL[6:4]	Pin interrupt channel Port select	000 = P0 PORT.
				(0<<0); // BSEL[2:0]	Pin interrupt channel bit select	001 = Pn.1. 
		PIPS5 = 
				(1<<4)| // PSEL[6:4]	Pin interrupt channel Port select	000 = P0 PORT.
				(7<<0); // BSEL[2:0]	Pin interrupt channel bit select	001 = Pn.1. 
	//========================================================
	//----MFP Config------------------------------------------
	//========================================================
		SFRS = 0x02;
		//========================================================
		//----MFP_UART Config-------------------------------------
		// MFP_UART0: P16_UART0_TXD		P17_UART0_RXD
		// MFP_UART2: P40_UART2_RXD		P41_UART2_TXD
		//========================================================
		P1MF76 &= 0xF0;		P1MF76 |= 0x03;		// MFP_P16_UART0_TXD;
		P1MF76 &= 0x0F;		P1MF76 |= 0x30;		// MFP_P17_UART0_RXD;
		P4MF10 &= 0xF0;		P4MF10 |= 0x08;		// MFP_P40_UART2_RXD;
		P4MF10 &= 0x0F;		P4MF10 |= 0x80;		// MFP_P41_UART2_TXD;
	//========================================================
	//----Wakeup timer and Uart and Timer Config--------------
	//========================================================
		SFRS = 0x00;
		//========================================================
		//--12S Wakeup WKT interrupt------------------------------
		//========================================================
		WKCON = // Self Wake-up Timer Control			 
				(0<<6)| // [7:6]:		Reserved
				(0<<5)| // WKTCK:		This bit is set WKT clock source select bit.
						// 0 = LIRC(38.4kHz)
				(0<<4)| // WKTF:		WKT overflow flag
						// This bit is not automatically cleared via hardware and should be cleared via software.
				(1<<3)| // WKTR:		WKT run control
						// 1 = WKT starts running.
				(7<<0); // WKPS[2:0]:	WKT pre-scalar
						// 000~111 = 1,4,16,64,256,512,1024,2048	7:1/2048
		RWK =  256-(38400*6/2048); // 86H, Page 0	Self Wake-up Timer Reload Byte
		//========================================================
		//----Uart Config-----------------------------------------
		// UART0_Timer3:
		//		UART0 using Timer 3 overflows as baud rate clocks
		//		1 start + 8 data + parity bit disable
		//========================================================
		PCON =	// Power Control
				(1<<7)|	// SMOD: Serial port 0 double baud rate enable
				(0<<6)|	// SMOD0: Serial port 0 framing error flag access enable.  0 = SCON.7 accesses to SM0 bit.
				(0<<5)|	// LPR: Low power run mode
				(0<<4)|	// POF: Power-on reset flag
				(0<<3)|	// GF1: General purpose flag 1
				(0<<2)|	// GF0 General purpose flag 0
				(0<<1)|	// PD Power-down mode
				(0<<0);	// IDL Idle mode

		SCON =	// Serial Port 0 Control (Bit-addressable)
				(0<<7)|	// SM0/FE Serial port mode select
				(1<<6)|	// SM1 SM[1:0]:serial port mode select.
				(0<<5)|	// SM2:For multiprocessor communication.  0 = Reception is always valid no matter the logic level of the 9th bit.
				(1<<4)|	// REN: Receiving enable
				(0<<3)|	// TB8: 9th transmitted bit
				(0<<2)|	// RB8: 9th received bit
				(0<<1)|	// TI: Transmission interrupt flag (his bit should be cleared manually via software.)
				(0<<0);	// RI: Receiving interrupt flag (his bit should be cleared manually via software.)
		//========================================================
		//----Uart Config-----------------------------------------
		// UART2_SC:
		//		8 data + 1 stop bit + parity bit disable
		//========================================================
		SC0CR0 |= SET_BIT0;		// set_SC0CR0_SCEN;			// Enable SC module
		SC0CR0 &= CLR_BIT3;		// clr_SC0CR0_AUTOCEN;
		SC0CR0 &= CLR_BIT4;		// clr_SC0CR0_CONSEL;		// clr CONSEL and AUTOCEN
		SC0CR0 |= SET_BIT7;		// set_SC0CR0_NSB;			// stop bit = 1bit
		
		SC0CR1 |= SET_BIT0;		// set_SC0CR1_UARTEN;		// set as UART mode
		SC0CR1 |= SET_BIT1;		// set_SC0CR1_CLKKEEP; 	 
		SC0CR1 |= SET_BIT6;		// set_SC0CR1_PBOFF;		// parity bit disable
		SC0CR1 &= 0xCF;										// datalegth 8bit
		//========================================================
		//----Timer Config----------------------------------------
		// Timer0:	Mode 1		Timer0 for time base is 1ms
		// Timer3:	Mode 2		UART0
		//========================================================
		TMOD =	// Timer 0 and 1 Control
				(0<<7)| // GATE[7]  : Timer 1 gate control.
						// GATE = 0;    Timer 1 will clock when TR1 is 1 regardless of nINT1 logic level.
						// GATE = 1;    Timer 1 will clock only when TR1 is 1 and nINT1 is logic 1.
				(0<<6)| // C/nT[6]  : Timer 1 Counter/Timer select.
						// C/nT = 0;    Timer 1 is incremented by internal system clock.
						// C/nT = 1;    Timer 1 is incremented by the falling edge of the external pin T1.
				(0<<4)| // M[5:4]   : Timer 1 mode select
						//  0: Mode 0   13-bit Timer/Counter
						//  1: Mode 1   16-bit Timer/Counter
						//  2: Mode 2   8-bit Timer/Counter with auto-reload from TH1
						//  3: Mode 3   Timer 1 halted
				(0<<3)| // GATE[3]  : Timer 0 gate control.
						// GATE = 0;    Timer 0 will clock when TR0 is 1 regardless of nINT0 logic level.
						// GATE = 1;    Timer 0 will clock only when TR0 is 1 and nINT0 is logic 1.
				(0<<2)| // C/nT[2]  : Timer 0 Counter/Timer select.
						// C/nT = 0;    Timer 0 is incremented by internal system clock.
						// C/nT = 1;    Timer 0 is incremented by the falling edge of the external pin T0.
				(1<<0); // M[1:0]   : Timer 0 mode select
						//  0: Mode 0   13-bit Timer/Counter
						//  1: Mode 1   16-bit Timer/Counter
						//  2: Mode 2   8-bit Timer/Counter with auto-reload from TH0
						//  3: Mode 3   TL0 as a 8-bit Timer/Counter and TH0 as a 8-bit Timer
	   
		CKCON =	// Clock Control
				(1<<7)| // FASTWK[7]: Fast Wakeup enable.
						// FASTWK = 0;  Faster Wakeup Disabled.
						// FASTWK = 1;  Faster Wakeup Enabled.
						//	   when system wakeup from power down mode,
						//	   HIRC clock stable time is about 3us.
				(0<<6)| // PWMCKS[6]: PWM clock source select
						// PWMCKS = 0;  The clock source of PWM is the system clock FSYS.
						// PWMCKS = 1;  The clock source of PWM is the overflow of Timer 1.
				(0<<5)| // T1OE[5]  : Timer 1 output enable
						// T1OE = 0;    Timer 1 output Disabled.
						// T1OE = 1;    Timer 1 output Enabled from T1 pin.
				(0<<4)| // T1M[4]   : Timer 1 clock mode select
						// T1M = 0;	   The clock source of Timer 0 is the system clock divided by 12.
						// T1M = 1;	   The clock source of Timer 1 is direct the system clock.
				(0<<3)| // T0M[3]   : Timer 0 clock mode select
						// T0M = 0;	   The clock source of Timer 0 is the system clock divided by 12.
						// T0M = 1;	   The clock source of Timer 0 is direct the system clock.
				(0<<2)| // T0OE[2]  : Timer 0 output enable
						// T0OE = 0;    Timer 0 output Disabled.
						// T0OE = 1;    Timer 0 output Enabled from T0 pin.
				(0<<1)| // CLOEN[1] : System clock output enable
						// CLOEN = 0;   System clock output Disabled.
						// CLOEN = 1;   System clock output Enabled from CLO pin.
				(0<<0); // Reserved
	   
		TCON =	// Timer 0 and 1 Control (Bit-addressable)
				(0<<7)| // TF1[7]   : Timer 1 overflow flag.
						// This bit can be set or cleared by software.
				(0<<6)| // TR1[6]   : Timer 1 run control.
						// TR1 = 0;	   Timer 1 Disabled.
						// TR1 = 1;	   Timer 1 Enabled.
				(0<<5)| // TF0[5]   : Timer 0 overflow flag.
						// This bit can be set or cleared by software.
				(1<<4)| // TR0[4]   : Timer 0 run control.
						// TR0 = 0;	   Timer 0 Disabled.
						// TR0 = 1;	   Timer 0 Enabled.
				(0<<3)| // IE1[3]   : External interrupt 1 edge flag.
				(0<<2)| // IT1[2]   : External interrupt 1 type select.
						// IT1 = 0;	   nINT1 is low level triggered.
						// IT1 = 1;	   nINT1 is falling edge triggered.
				(0<<1)| // IE0[1]   : External interrupt 0 edge flag.
				(1<<0); // IT0[0]   : External interrupt 0 type select.
						// IT0 = 0;	   nINT0 is low level triggered.
						// IT0 = 1;	   nINT0 is falling edge triggered.

		T3CON =	// Timer 3 Control	// Serial port 0 baud rate clock source = Timer1
				(0<<7)| // SMOD_1: Serial port 1 double baud rate enable
				(0<<6)| // SMOD0_1: Serial port 1 framing error access enable
				(1<<5)| // BRCK: Serial port 0 baud rate clock source
						// BRCK = 0;	Timer 1.
						// BRCK = 1;	Timer 3.
				(0<<4)| // TF3: Timer 3 overflow flag	  This bit can be set or cleared by software.
				(1<<3)| // TR3: Timer 3 run control
				(0<<0); // T3PS[2:0]: Timer 3 pre-scalar 	2^T3PS
		//========================================================
		//----TMR0 for time base----------------------------------
		//========================================================
		TH0 = TH0_INIT;
		TL0 = TL0_INIT;
		//========================================================
		//----Uart0 baud Config-----------------------------------
		//========================================================
		RH3 = ((unsigned char)((65536-(24000000/16/9600))>>8));
		RL3 = ((unsigned char)((65536-(24000000/16/9600))&0xFF));
		//========================================================
		//----Uart2 baud Config-----------------------------------
		//========================================================
		SC0ETURD1 = 0x30 | (((unsigned char)((24000000/8/115200-1)>>8))&0x0F);
					// SCDIV[6:4]: 011 = Fsc = Fsys/8	default
		SC0ETURD0 = ((unsigned char)((24000000/8/115200-1)&0xFF));
	//========================================================
	//----Software enable WDT reset CONFIG setting------------
	//========================================================
		SFRS = 0x00;
		//========================================================
/*		TA=0xAA;	TA=0x55;	CHPCON |= SET_BIT0;	// Enable IAP mode
		IAPAH = 0x00;	IAPAL = 0x04;	IAPFD = 0x0F;	IAPCN = 0xE1;
		TA=0xAA;	TA=0x55;	IAPUEN |= SET_BIT2;
		TA=0xAA;	TA=0x55;	IAPTRG |= SET_BIT0;	// trigger IAP
		while((CHPCON&SET_BIT6)==SET_BIT6);			// check IAPFF (CHPCON.6)
		TA=0xAA;	TA=0x55;	IAPUEN &= CLR_BIT2;
		TA=0xAA;	TA=0x55;	CHPCON &= CLR_BIT0;	// Disabled IAP mode
		//========================================================
		PCON &= CLR_BIT4;							// Clear Power-on reset flag
*/		//========================================================
		TA=0xAA;	TA=0x55;	WDCON = 0x07;		// Setting WDT prescale 
		TA=0xAA;	TA=0x55;	WDCON |= SET_BIT6;	// Clear WDT timer
		while((WDCON|~SET_BIT6)==0xFF); 			// Confirm WDT clear is ok before into power down mode
		TA=0xAA;	TA=0x55;	WDCON |= SET_BIT7;	// WDT run
	//========================================================
	//----Enable interrupt------------------------------------
	//========================================================
		SFRS = 0x00;
		//========================================================
		PIF = 0;		// Clr pin interrupt flag
		EIE0 |= 0x02;	// EPI@bit1 	Enable pin interrupt
		//========================================================
		WKCON &= 0xEF;	// WKTF@bit4	Clr WKT overflow flag
		EIE1  |= 0x04;	// EWKT@bit2	Enable WKT interrupt
		//========================================================
		ET0	= 1;		// Enable Timer 0 interrupt
		EA	= 1;		// Enable Global interrupt
		//========================================================
	//========================================================
}
//========================================================
// Function 	: 
// Function API : 
//========================================================
void Clear_WDT_Timer(void)
{
	//========================================================
	unsigned	char	b_Ea;
	//========================================================
	b_Ea = EA;
	EA = 0; 							// Disabled Global interrupt
	TA = 0xAA;	TA = 0x55;
	WDCON |= SET_BIT6;					// Clear WDT timer
//	while((WDCON|~SET_BIT6)==0xFF); 	// Confirm WDT clear is ok before into power down mode
	EA = b_Ea;							// Enable Global interrupt
	//========================================================
}
//========================================================
// Function 	: 
// Function API : 
//========================================================
void Enter_Deep_Sleep(void)
{
	//========================================================
	LED_PIN_RED = 1;
	LED_PIN_GREEN = 1;
	PIN_NSP_VBAT_CONTROL = 1;
	//========================================================
	TA = 0xAA;	TA = 0x55;
    CHPCON &= 0xFE;					// IAPEN@bit0	Disabled IAP mode
	//========================================================
	PIF  = 0x00;					// Clr pin interrupt flag
	EIE0|= 0x02;					// EPI@bit1		Enable pin interrupt
	//========================================================
	SC0IE &= CLR_BIT0;				// CLR_BIT0_ݵжʹλ
	SC0CR0&= CLR_BIT0;				// Disabled SC module
	//========================================================
	PCON |= 0x02;					// PD@bit1		to enter deep sleep
	//========================================================
	SC0IE |= SET_BIT0;				// SET_BIT0_ݵжʹλ
	SC0CR0|= SET_BIT0;				// Enable SC module
	//========================================================
	EIE0 &= 0xFD;					// EPI@bit1		Disabled pin interrupt
	//========================================================
	PIN_NSP_VBAT_CONTROL = 0;
	//========================================================
}
//========================================================
#endif
//========================================================
#if		1
//========================================================
// Function		: Timer0_1ms interrupt
// Function API	: 
//========================================================
void Timer0_1ms_ISR(void)interrupt 1			// Timer0 1ms interrupt		000BH	1
{
	//========================================================
	//--Interrupt per 1ms-------------------------------------
	//========================================================
	TF0 = 0;	// Clear TF0 (Timer0 Interrupt).
	//========================================================
	TH0 = TH0_INIT;
	TL0 = TL0_INIT;
	//========================================================
	ucTimeCount_Base++;
	//========================================================
	if( ucTimeCount_Base==0 )
		ucTimeBase_256ms++;
	//========================================================
}
//========================================================
// Function		: Wakeup_Pin interrupt
// Function API	: 
//========================================================
void Wakeup_Pin_ISR(void)	  interrupt 7		// Wakeup Pin interrupt
{   
	//========================================================
	//--Only for P01_WAKEUP wake up sleep---------------------
	//--P01_WAKEUP----High-level/falling-edge Wakeup interrupt
	//--P46_Key-------Low-level/falling-edge Wakeup interrupt-
	//--P40_UART2_RXD-Low-level/falling-edge Wakeup interrupt-
	//--P17_UART0_RXD-Low-level/falling-edge Wakeup interrupt-
	//========================================================
	if( (PIF&SET_BIT4)==SET_BIT4 )
		SMODE_API_Commu_Idle = 0;		// HTK5020_Mode Uart Wakeup
	else if( (PIF&SET_BIT0)==SET_BIT0 )
		SMODE_API_PinWakeup_Done = 0;	// HTK5020_Mode Wakeup	// bDevice_Key_Idle = 0;	// Device Key Wakeup
	else if( (PIF&SET_BIT1)==SET_BIT1 )
		bDevice_KeyAlarm_Done = 0;		// Device Key Wakeup	// bDevice_Key_Idle = 0;	// Device Key Wakeup
	else if( (PIF&SET_BIT5)==SET_BIT5 )
		bDevice_Commu_Idle = 0;			// Device Uart Wakeup
	//========================================================
	PIF = 0x00; 						// Clr pin interrupt flag
	//========================================================
}
//========================================================
// Function		: WakeUp_Timer interrupt
// Function API	: 
//========================================================
void WakeUp_Timer_ISR(void)   interrupt 17		// Wakeup Timer interrupt
{
	//========================================================
	//--Wakeup WKT interrupt----------------------------------
	//========================================================
	if( WKCON&0x10 )
	{
		//========================================================
		WKCON &= 0xEF;		// WKTF@bit4	Clr WKT overflow flag
		//========================================================
		if( SmokeMode_Alarm_6s )
			SmokeMode_Alarm_6s--;
		if( Smoke_Alarm_Disable )
			Smoke_Alarm_Disable--;
		if( ReadSmokeMessage_12s )
			ReadSmokeMessage_12s--;
		//========================================================
	}
	//========================================================
}
//========================================================
#endif
//========================================================
// Function	 	: 
// Function API	: 
// return		: None
//========================================================
