//========================================================
// Copyright(c) 2019 Nuvoton Technology Corp. All rights reserved.                                         */

// Nuvoton Technoledge Corp. 
// Website: http://www.nuvoton.com
// E-Mail : MicroC-8bit@nuvoton.com
// Date   : Apr/21/2019
//========================================================


//========================================================
// Section: Included Files
//========================================================
#include "../../../main.h"
//========================================================
// Section: Macro Declarations
//========================================================
volatile unsigned char	xdata	page_buffer[128];
//========================================================
#if		1
//========================================================
// Function 	: Read_APROM_BYTE
// Function API : Read Dataflash 
// param[in]	: u16_addr : Dataflash start address
// note			: None
// return		: Dataflash Value
// exmaple		: Read_APROM_BYTE(0x3802);
//======================================================== 
unsigned char Read_APROM_BYTE(unsigned int code *u16_addr)
{
	//========================================================
	return	*u16_addr>>8;
	//========================================================
}
//========================================================
// Function 	: Write_DATAFLASH_BYTE
// Function API : Write Dataflash as EEPROM
// param[in]	: u16_addr : Dataflash start address
//	u16EPAddr	: the 16bit EEPROM start address.
//					Any of APROM address can be defined as start address (0x3800)
//	u8EPData	: the 8bit value need storage in (0x3800)
// note			: None
// return		: None
// exmaple		: Write_DATAFLASH_BYTE(0x3882,0x34);
//======================================================== 
void Write_DATAFLASH_BYTE(unsigned int u16EPAddr,unsigned char u8EPData)
{
	//========================================================
	unsigned char	looptmp = 0;
	unsigned int	u16_addrl_r;
	unsigned int	RAMtmp;
	//========================================================
	u16_addrl_r = (u16EPAddr/128)*128;		//Check page start address
	//========================================================
	for(looptmp=0;looptmp<0x80;looptmp++)	//Save APROM data to XRAM0
	{
		//========================================================
		RAMtmp = Read_APROM_BYTE((unsigned int code *)(u16_addrl_r+looptmp));
		page_buffer[looptmp]=RAMtmp;
		//========================================================
	}
	//========================================================
	page_buffer[u16EPAddr&0x7f] = u8EPData;	// Modify customer data in XRAM
	//========================================================
	IAPAL = u16_addrl_r&0xff;				//Erase APROM DATAFLASH page
	IAPAH = (u16_addrl_r>>8)&0xff;
	//========================================================
	IAPFD = 0xFF;
	set_CHPCON_IAPEN; 
	set_IAPUEN_APUEN;
	IAPCN = 0x22;     
	set_IAPTRG_IAPGO; 
	//========================================================
	set_CHPCON_IAPEN; //Save changed RAM data to APROM DATAFLASH
	set_IAPUEN_APUEN;
	//========================================================
	IAPCN = 0x21;
	//========================================================
	for(looptmp=0;looptmp<0x80;looptmp++)
	{
		//========================================================
		IAPAL = (u16_addrl_r&0xff)+looptmp;
		IAPAH = (u16_addrl_r>>8)&0xff;
		IAPFD = page_buffer[looptmp];
		set_IAPTRG_IAPGO;      
		//========================================================
	}
	//========================================================
	clr_IAPUEN_APUEN;
	clr_CHPCON_IAPEN;
	//========================================================
}  
//========================================================
#endif
//========================================================
// Function		: 
// Function API	: 
// return		: None
//========================================================
