//========================================================
// Copyright(c) 2019 Nuvoton Technology Corp. All rights reserved.                                         */

// Nuvoton Technoledge Corp. 
// Website: http://www.nuvoton.com
// E-Mail : MicroC-8bit@nuvoton.com
// Date   : Apr/21/2019
//========================================================


//========================================================
// Section: Included Files
//========================================================
#include "../../../main.h"
//========================================================
// Section: Macro Declarations
//========================================================

//========================================================
#if		1
//========================================================
// Function	 	: GPIO_Pull_Enable
// Function API : GPIO Pull up or Pull down enable setting
// param[in]	: 
// u8Port		: Decides the GPIO port number: Port0 ~ Port5
// u8PinMask	: Decides bit of the port 
//					from SET_BIT0~SET_BIT7 use "|" to define multi bit
// u8PullMode	: Decides the GPIO Pull up or pull down (PullUp/PullDown)
// return		: none
// note			: none
// example		: GPIO_Pull_Enable(P1,SET_BIT0|SET_BIT5|SET_BIT7,PullUp);
//========================================================
void GPIO_Pull_Enable(unsigned char u8Port, unsigned char u8PinMask, unsigned char u8PullMode)
{
	//========================================================
	SFRS = 0x01;
	//========================================================
	switch (u8PullMode)
	{
		//========================================================
		case PullUp:
			//========================================================
			switch(u8Port)
			{
				//========================================================
				case Port0:	P0UP |= u8PinMask;	break;
				case Port1:	P1UP |= u8PinMask;	break;
				case Port2:	P2UP |= u8PinMask;	break;
				case Port3:	P3UP |= u8PinMask;	break;
				case Port4:	P4UP |= u8PinMask;	break;
				case Port5:	P5UP |= u8PinMask;	break;
				//========================================================
			}
			//========================================================
			break;
			//========================================================
		case PullDown:
			//========================================================
			switch(u8Port)
			{
				//========================================================
				case Port0:	P0DW |= u8PinMask;	break;
				case Port1:	P1DW |= u8PinMask;	break;
				case Port2:	P2DW |= u8PinMask;	break;
				case Port3:	P3DW |= u8PinMask;	break;
				case Port4:	P4DW |= u8PinMask;	break;
				case Port5:	P5DW |= u8PinMask;	break;
				//========================================================
			}
			//========================================================
			break;
			//========================================================
		//========================================================
	}
	//========================================================
	SFRS = 0x00;
	//========================================================
}
//========================================================
// Function	 	: GPIO_Pull_Disable
// Function API : GPIO Pull up or Pull down disable
// param[in]	: 
// u8Port		: Decides the GPIO port number: Port0 ~ Port5
// u8PinMask	: Decides bit of the port 
// 					from SET_BIT0~SET_BIT7 use "|" to define multi bit
// u8PullMode	: Decides the GPIO Pull up or pull down (PullUp/PullDown)
// return		: none
// note			: none
// example		: GPIO_Pull_Enable(P1,CLR_BIT0&CLR_BIT5,PullUp);
//========================================================
void GPIO_Pull_Disable(unsigned char u8Port, unsigned char u8PinMask, unsigned char u8PullMode)
{
	//========================================================
	SFRS = 0x01;
	//========================================================
	switch (u8PullMode)
	{
		//========================================================
		case PullUp:
			//========================================================
			switch(u8Port)
			{
				//========================================================
				case Port0:	P0UP &= ~u8PinMask;	break;
				case Port1:	P1UP &= ~u8PinMask;	break;
				case Port2:	P2UP &= ~u8PinMask;	break;
				case Port3:	P3UP &= ~u8PinMask;	break;
				case Port4:	P4UP &= ~u8PinMask;	break;
				case Port5:	P5UP &= ~u8PinMask;	break;
				//========================================================
			}
			//========================================================
			break;
			//========================================================
		case PullDown:
			//========================================================
			switch(u8Port)
			{
				//========================================================
				case Port0:	P0DW &= ~u8PinMask;	break;
				case Port1:	P1DW &= ~u8PinMask;	break;
				case Port2:	P2DW &= ~u8PinMask;	break;
				case Port3:	P3DW &= ~u8PinMask;	break;
				case Port4:	P4DW &= ~u8PinMask;	break;
				case Port5:	P5DW &= ~u8PinMask;	break;
				//========================================================
			}
			//========================================================
			break;
			//========================================================
		//========================================================
	}
	//========================================================
	SFRS = 0x00;
	//========================================================
}
//========================================================
// Function	 	: GPIO_SetMode
// Function API : GPIO mode setting
// param[in]	: 
// u8Port		: Decides the GPIO port number: Port0 ~ Port5
// u8PinMask	: Decides bit of the port 
//					from SET_BIT0~SET_BIT7 use "|" to define multi bit
// u8Mode		: Decides the GPIO mode.	for mode to select.
//					GPIO_MODE_INPUT / GPIO_MODE_PUSHPULL /
//					GPIO_MODE_QUASI / GPIO_MODE_OPENDRAI /
// return		: none
// note			: Confirm multi function pin is defined as GPIO first.
//					call function_define_ML51.h to define.
// example		: GPIO_SetMode(P1,0,GPIO_MODE_QUASI);
//========================================================
void GPIO_SetMode(unsigned char u8Port, unsigned char u8PinMask, unsigned char u8Mode)
{
	//========================================================
	unsigned char	u8PnM1, u8PnM2;
	//========================================================
	SFRS = 0x01;
	//========================================================
	switch(u8Port)
	{
		//========================================================
		case Port0:	u8PnM1 = P0M1;	u8PnM2 = P0M2;	break;
		case Port1:	u8PnM1 = P1M1;	u8PnM2 = P1M2;	break;
		case Port2:	u8PnM1 = P2M1;	u8PnM2 = P2M2;	break;
		case Port3:	u8PnM1 = P3M1;	u8PnM2 = P3M2;	break;
		case Port4:	u8PnM1 = P4M1;	u8PnM2 = P4M2;	break;
		case Port5:	u8PnM1 = P5M1;	u8PnM2 = P5M2;	break;
		//========================================================
	}
	//========================================================
	switch(u8Mode)
	{
		//========================================================
		case GPIO_MODE_QUASI:		u8PnM1 &= ~u8PinMask;	u8PnM2 &= ~u8PinMask;	break;
		case GPIO_MODE_PUSHPULL:	u8PnM1 &= ~u8PinMask;	u8PnM2 |= u8PinMask;	break;
		case GPIO_MODE_INPUT:		u8PnM1 |= u8PinMask; 	u8PnM2 &= ~u8PinMask;	break;
		case GPIO_MODE_OPENDRAIN:	u8PnM1 |= u8PinMask;	u8PnM2 |= u8PinMask;	break;
		//========================================================
	}
	//========================================================
	switch(u8Port)
	{
		//========================================================
		case Port0:	P0M1 = u8PnM1;			P0M2 = u8PnM2;		break;
		case Port1:	P1M1 = u8PnM1;			P1M2 = u8PnM2;		break;
		case Port2:	P2M1 = u8PnM1;			P2M2 = u8PnM2;		break;
		case Port3:	P3M1 = u8PnM1;			P3M2 = u8PnM2;		break;
		case Port4:	P4M1 = u8PnM1;			P4M2 = u8PnM2;		break;
		case Port5:	P5M1 = u8PnM1&0x0F;		P5M2 = u8PnM2&0x0F;	break;
		//========================================================
	}
	//========================================================
	SFRS = 0x00;
	//========================================================
}
//========================================================
#endif
//========================================================
#if		1
//========================================================
// Function 	: GPIO_EnableInt
// Function API : GPIO interrupt enable setting step
// param[in]	: 
// u8PIT		: Select pin interrupt channel PIT0~PIT7
// u8IntStatus	u8IntMode	: Select trig status 
//							HIGH	LEVEL	LOW		LEVEL	RISING
//							EDGE	FALLING	EDGE	BOTH	EDGE
// u8Port		u8Bit		: Define interrupt port (PORT, BIT)
// note			: None
// return		: None
// exmaple		: GPIO_EnableInt(PIT0,BOTH,EDGE,Port1,0)
// details		: means P1.0 falling edge trig pin intterrupt channel 0 (PIT0)
//======================================================== 
void GPIO_EnableInt(		unsigned char u8PIT,
							unsigned char u8IntStatus,	unsigned char u8IntMode,
							unsigned char u8Port,		unsigned char u8Bit)
{
	//========================================================
	SFRS = 0x01;
	//========================================================
	switch((u8IntMode<<4)+u8PIT)
	{
		//========================================================
		case 0x00:	PICON &= CLR_BIT0;	break;
		case 0x01:	PICON &= CLR_BIT1;	break;
		case 0x02:	PICON &= CLR_BIT2;	break;
		case 0x03:	PICON &= CLR_BIT3;	break;
		case 0x04:	PICON &= CLR_BIT4;	break;
		case 0x05:	PICON &= CLR_BIT5;	break;
		case 0x06:	PICON &= CLR_BIT6;	break;
		case 0x07:	PICON &= CLR_BIT7;	break;
		//========================================================
		case 0x10:	PICON |= SET_BIT0;	break;
		case 0x11:	PICON |= SET_BIT1;	break;
		case 0x12:	PICON |= SET_BIT2;	break;
		case 0x13:	PICON |= SET_BIT3;	break;
		case 0x14:	PICON |= SET_BIT4;	break;
		case 0x15:	PICON |= SET_BIT5;	break;
		case 0x16:	PICON |= SET_BIT6;	break;
		case 0x17:	PICON |= SET_BIT7;	break;
		//========================================================
		default:	break;
		//========================================================
	}
	//========================================================
	switch((u8IntStatus<<4)+u8PIT)
	{
		//========================================================
		case 0x00:	PINEN |= SET_BIT0;	PIPEN &= CLR_BIT0;	break;
		case 0x01:	PINEN |= SET_BIT1;	PIPEN &= CLR_BIT1;	break;
		case 0x02:	PINEN |= SET_BIT2;	PIPEN &= CLR_BIT2;	break;
		case 0x03:	PINEN |= SET_BIT3;	PIPEN &= CLR_BIT3;	break;
		case 0x04:	PINEN |= SET_BIT4;	PIPEN &= CLR_BIT4;	break;
		case 0x05:	PINEN |= SET_BIT5;	PIPEN &= CLR_BIT5;	break;
		case 0x06:	PINEN |= SET_BIT6;	PIPEN &= CLR_BIT6;	break;
		case 0x07:	PINEN |= SET_BIT7;	PIPEN &= CLR_BIT7;	break; 
		//========================================================
		case 0x10:	PINEN &= CLR_BIT0;	PIPEN |= SET_BIT0;	break;
		case 0x11:	PINEN &= CLR_BIT1;	PIPEN |= SET_BIT1;	break;
		case 0x12:	PINEN &= CLR_BIT2;	PIPEN |= SET_BIT2;	break;
		case 0x13:	PINEN &= CLR_BIT3;	PIPEN |= SET_BIT3;	break;
		case 0x14:	PINEN &= CLR_BIT4;	PIPEN |= SET_BIT4;	break;
		case 0x15:	PINEN &= CLR_BIT5;	PIPEN |= SET_BIT5;	break;
		case 0x16:	PINEN &= CLR_BIT6;	PIPEN |= SET_BIT6;	break;
		case 0x17:	PINEN &= CLR_BIT7;	PIPEN |= SET_BIT7;	break;  
		//========================================================
		case 0x20:	PINEN |= SET_BIT0;	PIPEN |= SET_BIT0;	break; 
		case 0x21:	PINEN |= SET_BIT1;	PIPEN |= SET_BIT1;	break; 
		case 0x22:	PINEN |= SET_BIT2;	PIPEN |= SET_BIT2;	break; 
		case 0x23:	PINEN |= SET_BIT3;	PIPEN |= SET_BIT3;	break; 
		case 0x24:	PINEN |= SET_BIT4;	PIPEN |= SET_BIT4;	break; 
		case 0x25:	PINEN |= SET_BIT5;	PIPEN |= SET_BIT5;	break; 
		case 0x26:	PINEN |= SET_BIT6;	PIPEN |= SET_BIT6;	break; 
		case 0x27:	PINEN |= SET_BIT7;	PIPEN |= SET_BIT7;	break; 
		//========================================================
		default:	break;      
		//========================================================
	}                                            
	//========================================================
	switch(u8PIT)                                
	{                                            
		//========================================================
		case PIT0:	PIPS0 = 0x00;	PIPS0 = (u8Port<<4)+(u8Bit&0x0F);	break;      
		case PIT1:	PIPS1 = 0x00;	PIPS1 = (u8Port<<4)+(u8Bit&0x0F);	break;                    
		case PIT2:	PIPS2 = 0x00;	PIPS2 = (u8Port<<4)+(u8Bit&0x0F);	break;  
		case PIT3:	PIPS3 = 0x00;	PIPS3 = (u8Port<<4)+(u8Bit&0x0F);	break;   
		case PIT4:	PIPS4 = 0x00;	PIPS4 = (u8Port<<4)+(u8Bit&0x0F);	break;   
		case PIT5:	PIPS5 = 0x00;	PIPS5 = (u8Port<<4)+(u8Bit&0x0F);	break;
		case PIT6:	PIPS6 = 0x00;	PIPS6 = (u8Port<<4)+(u8Bit&0x0F);	break;
		case PIT7:	PIPS7 = 0x00;	PIPS7 = (u8Port<<4)+(u8Bit&0x0F);	break;   
		//========================================================
		default:	break;
		//========================================================
	}
	//========================================================
	SFRS = 0x00;
	//========================================================
	EIE0 |= SET_BIT1;	//set_EIE0_EPI;	//Pin interrupt enable bit
	//========================================================
}
//========================================================
#endif
//========================================================
// Function	 	: 
// Function API	: 
// return		: None
//========================================================
